class IOTInternal(object):
  def __init__(self, internal):
    self.internal = internal
  def get_id(self):
    return self.internal['id']

class IOTDevice(IOTInternal):
  def __init__(self, internal):
    super().__init__(internal)
    self.data = None

class IOTDataField(IOTInternal):
  def __init__(self, internal):
    super().__init__(internal)
  def get_unit(self):
    return self.internal

class IOTDataEntries(object):
  def __init__(self, data, device, field):
    self.data = data
    self.field = field
    print (field)
    self.device = device
  def get_data(self):
    X = []
    Y = []
    for x in self.data:
      Y.append(x["value"])
      X.append(x["created_at"])
    return {"X" : X, "Y" : Y}

  def get_unit(self):
    return self.field.get_unit();



import requests
from models import IOTDevice, IOTDataField, IOTDataEntries

class Api(object):
  def __init__(self, key, https=True):
    self.key = key
    self.https = https
    self.api_domain = "datalog.anglebrackets.co.za"
    self.auth_header = {"Authorization" : "Bearer " + self.key}
    self.devices = []
    self.fields = []

  def _get_base_url(self):
    if self.https:
      base_url = "https://"
    else:
      base_url = "http://"
    return base_url + self.api_domain + "/api/"

  def _get_fields_url(self):
    return self._get_base_url() + 'fields'

  def _get_devices_url(self):
    return self._get_base_url() + 'devices'

  def _get_entries_url(self, device_id, field_id):
    return self._get_base_url() + 'entries/' + device_id + '/' + field_id
  
  def set_key(self, key):
    self.key = key

  def get_devices(self):
   datalog_response = requests.get(self._get_devices_url(), headers=self.auth_header)
   datalog_response.raise_for_status()
   for d in datalog_response.json():
     self.devices.append(IOTDevice(d));
   return self.devices

  def get_fields(self):
   datalog_response = requests.get(self._get_devices_url(), headers=self.auth_header)
   datalog_response.raise_for_status()
   for d in datalog_response.json():
     self.fields.append(IOTDataField(d));
   return self.fields

  def get_entries(self, device, field):
   datalog_response = requests.get(self._get_entries_url(str(device.get_id()), str(field.get_id())), headers=self.auth_header)
   datalog_response.raise_for_status()
   return IOTDataEntries(datalog_response.json(), device, field)


  



import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
  name = 'iotdatalog',
  packages = ['iotdatalog'],
  version = '0.1.1',
  license='GPL',
  description = 'Wrapper for datalog.anglebrackets.co.za REST API',
  author = 'Ruan Luies',
  author_email = 'omega@live.co.za',
  url = 'https://github.com/baggins800/iotdatalog',
  download_url = 'https://github.com/baggins800/iotdatalog/archive/iotdatalog-0.1.tar.gz',
  keywords = ['IOT', 'datalogging', 'datalog', 'datalogger'],
  install_requires=[  
    'requests>=1.6', 'responses'
  ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
  ],
)
